# ProgettoBIO

## To run the server

> export FLASK_APP=server

> flask run

Then head over to the react client (https://github.com/Pier297/BioSearch)
and execute:

> npm start

## OBIETTIVI:
mancherebbero le relazioni gene-gene e chemical-chemical


- Aggiungere biobert QA


Secondario:
- [EFFICIENZA] Per estrarre le relazioni converrebbe chiamare il modello in batch e non una singola frase alla volta
